菊次郎的夏天 (豆瓣)
Description: 菊次郎的夏天电影简介和剧情介绍,菊次郎的夏天影评、图片、预告片、影讯、论坛、在线购票
Keywords: 菊次郎的夏天,菊次郎の夏,菊次郎的夏天影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.114豆瓣电影Top250

# 菊次郎的夏天 菊次郎の夏 (1999)

导演: 北野武
编剧: 北野武
主演: 北野武 / 关口雄介 / 岸本加世子 / 吉行和子 / 细川典江 / 大家由祐子 / 磨赤儿 / 铃木忠幸 / 井手博士 / 今村鼠 / 兼子二郎 / 田中要次 / 小岛可奈子
类型: 剧情 / 喜剧
制片国家/地区: 日本
语言: 日语
上映日期: 2020-09-25(中国大陆) / 1999-05-20(戛纳电影节) / 1999-06-05(日本)
片长: 121分钟
又名: 菊次郎之夏 / Kikujirô no natsu / Kikujiro
IMDb: tt0199683
豆瓣评分
引用
8.9
563980人评价
5星
54.1%
4星
36.3%
3星
8.6%
2星
0.8%
1星
0.2%
好于 98% 剧情片
好于 99% 喜剧片
想看 看过
评价:
推荐

## 菊次郎的夏天的剧情简介 · · · · · ·

暑假到来，自幼丧父的小学三年级学生正男（关口雄介饰），如今和奶奶生活在一起，暑假特别无聊。他拿出母亲从外地寄回的信，准备自己一个人去爱知县丰桥市看望母亲。
邻居阿姨（岸本加世子饰）发现后，决定帮正男完成心愿。她拿出一笔钱做为旅费，还安排游手好闲的老公菊次郎（北野武饰）陪伴正男一起踏上寻母之途。可是在第一天，菊次郎就把老婆给的钱全部输光，于是两个人只好步行前往爱知。
一路搭顺风车，惹了不少麻烦后，菊次郎终于带着正男到了他母亲的家，但小男孩却十分沮丧。归途中，菊次郎努力安慰他，二人过得十分愉快，夏天就这么过去了。 ©豆瓣

## 菊次郎的夏天的演职员 · · · · · · ( 全部 20 )

- 北野武 导演
- 北野武 饰 菊次郎
- 关口雄介 饰 正男
- 岸本加世子 饰 菊次郎的妻子
- 吉行和子 演员
- 细川典江 演员

## 菊次郎的夏天的视频和图片 · · · · · · ( 预告片4 | 视频评论1 · 添加 | 图片1361 · 添加 )

## 菊次郎的夏天的获奖情况 · · · · · · ( 全部 )

- 第52届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 北野武

- 第23届日本电影学院奖
- 最佳影片(提名)

- 第23届日本电影学院奖
- 最佳女配角
- 岸本加世子

## 喜欢这部电影的人也喜欢 · · · · · ·

  一一

  小森林 夏秋篇

  重庆森林

  花样年华

  阿飞正传

  海上钢琴师

  东邪西毒

  天使爱美丽

  布达佩斯大饭店

  爱在黎明破晓前

我要写短评

## 菊次郎的夏天的短评 · · · · · · ( 全部 145938 条 )

热门 / 最新 / 好友

### 9550 有用 大头绿豆 看过 2005-09-04 15:05:33

从没见过那么流氓的温柔，从没见过那么温柔的流氓。

### 4976 有用 icancu 看过 2007-09-16 00:41:30

北斗七星的来由：一个小女孩走了很久的路为她发烧的母亲找水，晕倒在路上，醒来时看到自己的水斗里盛满了水，她开心地要跑回家，这时来了一只很渴的小狗，她把水喂了它，水斗就变成银色的，升上了天空。 　　即便自己缺少爱，也带给别人爱，因为头上有北斗。 　　每个人都在旅行，有目的的，没方向的。有的人一直在走，有的人原地呆着，但我们都会经历很多人事，去遇见，或是被遇见。夏天，就这么结束。

### 4495 有用 曾公豹 看过 2017-02-11 20:58:13

100个人看到片名，都会以为菊次郎是片中小男孩，哪怕看过了，以后看到片名，还是会这样认为。

### 4401 有用 丁一 看过 2018-05-18 20:24:18

北野武与老母不和。事业稍有起色，老母就每月催他寄钱回家，偶有延迟，便来电破口大骂。母亲的贪婪势利让北野十分气恨，老母去世时甚至不想回家奔丧。后来，北野武的大哥交给他两件母亲留给他的遗物：一封信和一张存折。信里写道：我儿，你从小就生性浪荡，我担心你日后一无所有…存折里有一千万圆

### 3857 有用 王大根 看过 2014-02-17 21:23:07

哈哈哈哈哈哈哈肚子都笑出波浪了。夏天真是一个奇怪的季节，明明实际上经历的只不过是黏糊糊的一身臭汗，可是总是忍不住将其与青春之类相联系，然后在夏天以外的季节回想起来的时候就特别特别怀念。每年都要陷入这样骗局似的怀念里。

> 更多短评 145938条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 菊次郎的夏天的影评 · · · · · · ( 全部 2294 条 )

热门 / 最新 / 好友
呱啦啦 2006-06-05 11:42:10

## 北野武的感恩与供养

“这是一部关于童年的电影，一部关于成长的电影，关于夏天的电影。” “一个不快乐的中年人，不希望看到一个不快乐的小孩子。是因为想起自己不快乐的童年，还是因为什么？” 很多人起先都以为那个木讷内向又孤独的小男孩是菊次郎，后来到结尾处北野大叔笑着说出“是菊... (展开)
5522 104 368回应 收起
Cary C 2012-02-13 01:48:10

## 《菊次郎的夏天》B面

一 　　毋庸置疑,《菊次郎的夏天》不但是北野武最好的力作,也是世界电影史上难得的经典。可惜的是,就像沉迷爱情的人们很难精准表达爱情的美妙一样,很多观众也说不清他们究竟被这部电影的什么“蛊惑”了,以致当电影结束时,眼中噙着伤感的泪花,脸上却绽放欣慰的笑容。这种怪诞... (展开)
4263 50 202回应 收起
楼贰贰 2006-05-19 19:14:39

## 八格呀路，夏天

影片的最末，正郎对着武田问：先生，你叫什么名字？ ---他妈的，菊次郎。 这个叫菊次郎的男人还是以足够让人喷饭的回答方式结束了旅程。小正郎则背着有天使翅膀的书包，依旧在久石让的那首欢快清新的音乐声中奔跑起来。 很久没有在一部影片中这样放肆笑过了，不由地想起另一个... (展开)
1205 54 69回应 收起
隆咚锵 2008-06-01 16:22:00

## 以儿童的名义，祝我自己

据说这部片本来不叫《菊次郎之夏》，打算叫什么《正南找妈妈》一类的开门见山的题目。纵然，这个片子有大片大片的绿色，久石让的配乐，我个人最喜欢的还是这个题目，实在得让人汗颜。这条找妈妈的漫漫长路上到底是正南的学到了更多还是菊次郎呢，到底是孩子的快乐大本营还是成... (展开)
314 31 82回应 收起
王恶 2013-04-30 18:48:23

## 你不懂我，因为我是摩羯座。

北野武是我唯一的偶像，但《菊次郎的夏天》不是我最喜欢的片子，我心血来潮看看差评，又看了好评，又看了热评。毫无疑问，很多评论有挂羊头卖狗肉的嫌疑，整篇评论跟片子的关系就只有一个片名了。另外一些评论也充斥着中种种误读。我冲动之下也就想写些废话。 “你不懂我，因为... (展开)
300 13 40回应 收起
粟度 2005-08-19 14:13:47

## 夜幕下的星光

周日午后，阳光透过徐徐摇摆的白色纱帘渗进房间，音箱里，罗斯特罗波维奇的大提琴声比往常更好听。书桌上有点凌乱，凌乱之中比较显眼的几样东西包括：几十粒未洗的红色水果，一壶透明玻璃壶泡出的茶，还有今天早上刚刚看过的碟片，名字叫《菊次郎之夏》。 北野武作品。 中学... (展开)
158 14 39回应 收起
东 2020-06-13 13:01:13 #《菊次郎的夏天》在北野武的作品序列里是什么水准和地位？

## 《菊次郎的夏天》在北野武的作品序列里是什么水准和地位？

这个夏天的午夜，看了菊次郎的夏天这部影片。心理酸酸的，有我自己的理解，同时真心佩服这种巧妙的剧作方式 1、说真的，刚开始以为小孩是菊次郎。 2、看看看着，原来大叔是菊次郎 3、又看一遍，他俩都不是菊次郎，小孩叫正男，大叔叫武田 4、再次试着快速看了一遍，大叔和小孩... (展开)
120 5 21回应 收起
郁程 2010-08-16 08:58:12

## 那么，我走了

一个人走啊走 遇到了一些人 有时候就抱怨说，我寂寞我空虚，求搭讪。 于是和某个人一起走了一段路。 后来就开始抱怨，一个人嫌闷，两个人嫌烦。 再后来就成了那种偶尔出现一下的人物，走一会，不走了。管谁和谁上路呢？ 我要这个时间段一个人走，那个时间段有人陪着走，随... (展开)
137 11 37回应 收起
西凉茉 2018-05-15 20:13:39

## 夏日之下人情人性都变的如阳光般透彻。

这篇影评可能有剧透

相对于社会的现实，我更愿意说人性还是美好的。北野武饰演的中年痞子可以为了男孩一个小小的梦想而奔走，暴走族为了让他开心而表演各种各样的节目。夏日之下人情人性都变的如阳光般透彻。 影片诸多情节十分搞笑，但整体的氛围却是充满了温情。所以，用搞笑来形容这部影片，显的... (展开)
59 1 4回应 收起

> 更多影评 2294篇

添加新讨论

## 讨论区 · · · · · ·

开心 暖心 走心 | 来自明明 |  | 2022-11-13 21:26:17
细思极恐：菊次郎抢了车之后，准备开车，后车门开... | 来自负 | 10 回应 | 2022-11-12 23:02:21
那个司机被打死了吗？ | 来自香草丘丘胶 | 8 回应 | 2022-11-04 23:46:43
菊次郎有杀人吗？ | 来自。 |  | 2022-11-04 19:38:19
第一个让我看睡着的电影 | 来自猪不愣登 | 9 回应 | 2022-10-26 09:11:07

> 去这部影片的讨论区（全部345条）

## 关于《菊次郎的夏天》的问题 · · · · · · ( 全部15个 )

- 为什么不叫《正男的夏天》？ 4人回答
- 小孩母亲的故居，住的那个家庭主妇叫什么名字？ 3人回答

> 全部15个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 西瓜视频 免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- L.J.Y
  1分钟前 看过
- cassandra
  5分钟前 看过
- Lissa
  5分钟前 想看

879632人看过 / 384698人想看

订阅菊次郎的夏天的评论:
feed: rss 2.0